@@ -8,7 +8,6 @@
 from __future__ import absolute_import, print_function
 
 import os
-import re
 import sys
 
 from .qtcore import (
@@ -29,7 +28,6 @@ from .qtgui import (
     QTextBrowser,
     QTextOption,
     QVBoxLayout,
-    qApp,
 )
 
 from mercurial import (
@@ -86,28 +84,27 @@ class BugReport(QDialog):
         tb = QTextBrowser()
         self.text = self.gettext(opts)
         tb.setHtml('<pre>' + qtlib.htmlescape(self.text, False) + '</pre>')
-        tb.setWordWrapMode(QTextOption.NoWrap)
+        tb.setWordWrapMode(QTextOption.WrapMode.NoWrap)
         layout.addWidget(tb)
 
         self.download_url_lbl = QLabel(_('Checking for updates...'))
         self.download_url_lbl.setMouseTracking(True)
-        self.download_url_lbl.setTextInteractionFlags(Qt.LinksAccessibleByMouse)
+        self.download_url_lbl.setTextInteractionFlags(Qt.TextInteractionFlag.LinksAccessibleByMouse)
         self.download_url_lbl.setOpenExternalLinks(True)
         layout.addWidget(self.download_url_lbl)
 
         # dialog buttons
-        BB = QDialogButtonBox
-        bb = QDialogButtonBox(BB.Ok|BB.Save)
-        bb.button(BB.Ok).clicked.connect(self.accept)
-        bb.button(BB.Save).clicked.connect(self.save)
-        bb.button(BB.Ok).setDefault(True)
-        bb.addButton(_('Copy'), BB.HelpRole).clicked.connect(self.copyText)
-        bb.addButton(_('Quit'), BB.DestructiveRole).clicked.connect(qApp.quit)
+        bb = QDialogButtonBox(QDialogButtonBox.StandardButton.Ok|QDialogButtonBox.StandardButton.Save)
+        bb.button(QDialogButtonBox.StandardButton.Ok).clicked.connect(self.accept)
+        bb.button(QDialogButtonBox.StandardButton.Save).clicked.connect(self.save)
+        bb.button(QDialogButtonBox.StandardButton.Ok).setDefault(True)
+        bb.addButton(_('Copy'), QDialogButtonBox.ButtonRole.HelpRole).clicked.connect(self.copyText)
+        bb.addButton(_('Quit'), QDialogButtonBox.ButtonRole.DestructiveRole).clicked.connect(QApplication.instance().quit)
         layout.addWidget(bb)
 
         self.setWindowTitle(_('TortoiseHg Bug Report'))
         self.setWindowFlags(self.windowFlags() & \
-                            ~Qt.WindowContextHelpButtonHint)
+                            ~Qt.WindowType.WindowContextHelpButtonHint)
         self.resize(650, 400)
         self._readsettings()
 
@@ -135,7 +132,7 @@ class BugReport(QDialog):
             return hglib.tounicode(ext)
 
         # TODO: make this more uniformly unicode safe
-        text = '#!python\n' # Bitbucket wiki marker for python code
+        text = '#!python\n'
         text += '** Mercurial version (%s).  TortoiseHg version (%s)\n' % (
                 hglib.hgversion, version.version())
         text += '** Command: %s\n' % (hglib.tounicode(opts.get('cmd', 'N/A')))
@@ -151,10 +148,7 @@ class BugReport(QDialog):
         text += ('** Qt-%s PyQt-%s QScintilla-%s\n'
                  % (QT_VERSION_STR, PYQT_VERSION_STR, QSCINTILLA_VERSION_STR))
         text += hglib.tounicode(opts.get('error', 'N/A'))
-        # Bitbucket wiki marker for code: 4 spaces indent (Markdown syntax)
-        regexp = re.compile(r'^', re.MULTILINE)
-        text = regexp.sub(r'    ', text)
-        return text
+        return "```" + text + "```"
 
     def copyText(self):
         QApplication.clipboard().setText(self.text)
@@ -212,12 +206,12 @@ class ExceptionMsgBox(QDialog):
     """Message box for recoverable exception"""
     def __init__(self, main, text, opts, parent=None):
         super(ExceptionMsgBox, self).__init__(parent)
-        self.setWindowFlags(self.windowFlags() & ~Qt.WindowContextHelpButtonHint)
+        self.setWindowFlags(self.windowFlags() & ~Qt.WindowType.WindowContextHelpButtonHint)
         self.setWindowTitle(_('TortoiseHg Error'))
 
         self._opts = opts
 
-        labelflags = Qt.TextSelectableByMouse | Qt.LinksAccessibleByMouse
+        labelflags = Qt.TextInteractionFlag.TextSelectableByMouse | Qt.TextInteractionFlag.LinksAccessibleByMouse
 
         self.setLayout(QVBoxLayout())
 
@@ -245,10 +239,10 @@ class ExceptionMsgBox(QDialog):
         self._textlabel.setWordWrap(False)
         self.layout().addWidget(self._textlabel)
 
-        bb = QDialogButtonBox(QDialogButtonBox.Close, centerButtons=True)
+        bb = QDialogButtonBox(QDialogButtonBox.StandardButton.Close, centerButtons=True)
         bb.rejected.connect(self.reject)
         self.layout().addWidget(bb)
-        desktopgeom = qApp.desktop().availableGeometry()
+        desktopgeom = QApplication.primaryScreen().availableGeometry()
         self.resize(desktopgeom.size() * 0.20)
 
     @pyqtSlot(str)
