@@ -280,14 +280,14 @@ class CmdProc(CmdWorker):
         proc.finished.connect(self._finish)
         proc.readyReadStandardOutput.connect(self._stdout)
         proc.readyReadStandardError.connect(self._stderr)
-        proc.error.connect(self._handleerror)
+        proc.errorOccurred.connect(self._handleerror)
 
     def startCommand(self, cmdline, uihandler):
         # type: (List[Text], UiHandler) -> None
         self._uihandler = uihandler
         fullcmdline = _proccmdline(self._ui, _localprocexts)
         fullcmdline.extend(cmdline)
-        self._proc.start(fullcmdline[0], fullcmdline[1:], QIODevice.ReadOnly)
+        self._proc.start(fullcmdline[0], fullcmdline[1:], QIODevice.OpenModeFlag.ReadOnly)
 
     def abortCommand(self):
         # type: () -> None
@@ -297,7 +297,7 @@ class CmdProc(CmdWorker):
 
     def isCommandRunning(self):
         # type: () -> bool
-        return self._proc.state() != QProcess.NotRunning
+        return self._proc.state() != QProcess.ProcessState.NotRunning
 
     @pyqtSlot(int)
     def _finish(self, ret):
@@ -306,11 +306,11 @@ class CmdProc(CmdWorker):
 
     @pyqtSlot(QProcess.ProcessError)
     def _handleerror(self, error):
-        if error == QProcess.FailedToStart:
+        if error == QProcess.ProcessError.FailedToStart:
             self.outputReceived.emit(_('failed to start command\n'),
                                      'ui.error')
             self._finish(-1)
-        elif error != QProcess.Crashed:
+        elif error != QProcess.ProcessError.Crashed:
             self.outputReceived.emit(_('error while running command\n'),
                                      'ui.error')
 
@@ -361,9 +361,9 @@ class CmdServer(CmdWorker):
         _fixprocenv(proc)
         if cwd:
             proc.setWorkingDirectory(cwd)
-        proc.error.connect(self._onServiceError)
+        proc.errorOccurred.connect(self._onServiceError)
         proc.finished.connect(self._onServiceFinished)
-        proc.setReadChannel(QProcess.StandardOutput)
+        proc.setReadChannel(QProcess.ProcessChannel.StandardOutput)
         proc.readyRead.connect(self._onReadyRead)
         proc.readyReadStandardError.connect(self._onReadyReadError)
         return proc
@@ -420,7 +420,7 @@ class CmdServer(CmdWorker):
     @pyqtSlot(QProcess.ProcessError)
     def _onServiceError(self, error):
         self._emitError(self._proc.errorString())
-        if error == QProcess.FailedToStart:
+        if error == QProcess.ProcessError.FailedToStart:
             self._onServiceFinished()
 
     @pyqtSlot()
@@ -725,10 +725,10 @@ class CmdSession(QObject):
         # pseudo FIFO between client "rbuf" and worker "wbuf"; not efficient
         # for large data since all outputs will be stored in memory
         if enabled:
-            self._dataoutrbuf.open(QIODevice.ReadOnly | QIODevice.Truncate)
+            self._dataoutrbuf.open(QIODevice.OpenModeFlag.ReadOnly | QIODevice.OpenModeFlag.Truncate)
             dataoutwbuf = QBuffer(self._dataoutrbuf.buffer())
             dataoutwbuf.bytesWritten.connect(self.readyRead)
-            dataoutwbuf.open(QIODevice.WriteOnly)
+            dataoutwbuf.open(QIODevice.OpenModeFlag.WriteOnly)
         else:
             self._dataoutrbuf.close()
             dataoutwbuf = None
