@@ -228,7 +228,7 @@ class LogWidget(qscilib.ScintillaCompat):
         self.setReadOnly(True)
         self.setUtf8(True)
         self.setMarginWidth(1, 0)
-        self.setWrapMode(QsciScintilla.WrapCharacter)
+        self.setWrapMode(QsciScintilla.WrapMode.WrapCharacter)
         self._initfont()
         self._initmarkers()
         qscilib.unbindConflictedKeys(self)
@@ -245,7 +245,7 @@ class LogWidget(qscilib.ScintillaCompat):
     def _initmarkers(self):
         self._markers = {}
         for l in ('ui.error', 'ui.warning', 'control'):
-            self._markers[l] = m = self.markerDefine(QsciScintilla.Background)
+            self._markers[l] = m = self.markerDefine(QsciScintilla.MarkerSymbol.Background)
             c = QColor(qtlib.getbgcoloreffect(l))
             if c.isValid():
                 self.setMarkerBackgroundColor(c, m)
@@ -285,7 +285,7 @@ class LogWidget(qscilib.ScintillaCompat):
 
     def keyPressEvent(self, event):
         # propagate key events important for dialog
-        if event.key() == Qt.Key_Escape:
+        if event.key() == Qt.Key.Key_Escape:
             event.ignore()
             return
         super(LogWidget, self).keyPressEvent(event)
@@ -313,9 +313,9 @@ class InteractiveUiHandler(cmdcore.UiHandler):
     def getLineInput(self):
         mode = self._promptmode
         if mode == cmdcore.UiHandler.TextInput:
-            return self._getTextInput(QLineEdit.Normal)
+            return self._getTextInput(QLineEdit.EchoMode.Normal)
         elif mode == cmdcore.UiHandler.PasswordInput:
-            return self._getTextInput(QLineEdit.Password)
+            return self._getTextInput(QLineEdit.EchoMode.Password)
         elif mode == cmdcore.UiHandler.ChoiceInput:
             return self._getChoiceInput()
         else:
@@ -330,20 +330,20 @@ class InteractiveUiHandler(cmdcore.UiHandler):
 
     def _getChoiceInput(self):
         msg, choicepairs = hglib.extractchoices(self._prompttext)
-        dlg = QMessageBox(QMessageBox.Question, _('TortoiseHg Prompt'), msg,
-                          QMessageBox.NoButton, self._parentWidget())
-        dlg.setWindowFlags(Qt.Sheet)
-        dlg.setWindowModality(Qt.WindowModal)
+        dlg = QMessageBox(QMessageBox.Icon.Question, _('TortoiseHg Prompt'), msg,
+                          QMessageBox.StandardButton.NoButton, self._parentWidget())
+        dlg.setWindowFlags(Qt.WindowType.Sheet)
+        dlg.setWindowModality(Qt.WindowModality.WindowModal)
         for r, t in choicepairs:
-            button = dlg.addButton(t, QMessageBox.ActionRole)
+            button = dlg.addButton(t, QMessageBox.ButtonRole.ActionRole)
             button.response = r
             if r == self._promptdefault:
                 dlg.setDefaultButton(button)
         # cancel button is necessary to close prompt dialog with empty response
-        dlg.addButton(QMessageBox.Cancel).hide()
+        dlg.addButton(QMessageBox.StandardButton.Cancel).hide()
         dlg.exec_()
         button = dlg.clickedButton()
-        if button and dlg.buttonRole(button) == QMessageBox.ActionRole:
+        if button and dlg.buttonRole(button) == QMessageBox.ButtonRole.ActionRole:
             return button.response
 
     def _parentWidget(self):
@@ -359,7 +359,7 @@ class PasswordUiHandler(InteractiveUiHandler):
     def getLineInput(self):
         mode = self._promptmode
         if mode == cmdcore.UiHandler.PasswordInput:
-            return self._getTextInput(QLineEdit.Password)
+            return self._getTextInput(QLineEdit.EchoMode.Password)
         else:
             return ''
 
@@ -400,14 +400,14 @@ class CmdSessionControlWidget(QWidget):
 
         # bottom buttons
         self._buttonbox = buttons = QDialogButtonBox()
-        self._cancelBtn = buttons.addButton(QDialogButtonBox.Cancel)
+        self._cancelBtn = buttons.addButton(QDialogButtonBox.StandardButton.Cancel)
         self._cancelBtn.clicked.connect(self.abortCommand)
 
-        self._closeBtn = buttons.addButton(QDialogButtonBox.Close)
+        self._closeBtn = buttons.addButton(QDialogButtonBox.StandardButton.Close)
         self._closeBtn.clicked.connect(self.reject)
 
         self._detailBtn = buttons.addButton(_detailbtntextmap[logVisible],
-                                            QDialogButtonBox.ResetRole)
+                                            QDialogButtonBox.ButtonRole.ResetRole)
         self._detailBtn.setAutoDefault(False)
         self._detailBtn.setCheckable(True)
         self._detailBtn.setChecked(logVisible)
@@ -481,22 +481,22 @@ class CmdSessionControlWidget(QWidget):
             ret = QMessageBox.question(self, _('Confirm Exit'),
                         _('Mercurial command is still running.\n'
                           'Are you sure you want to terminate?'),
-                        QMessageBox.Yes | QMessageBox.No,
-                        QMessageBox.No)
-            if ret == QMessageBox.Yes:
+                        QMessageBox.StandardButton.Yes | QMessageBox.StandardButton.No,
+                        QMessageBox.StandardButton.No)
+            if ret == QMessageBox.StandardButton.Yes:
                 self.abortCommand()
             return
 
         self.finished.emit(self._session.exitCode())
 
     def _updateSizePolicy(self):
-        if self.testAttribute(Qt.WA_WState_OwnSizePolicy):
+        if self.testAttribute(Qt.WidgetAttribute.WA_WState_OwnSizePolicy):
             return
         if self.isLogVisible():
-            self.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Expanding)
+            self.setSizePolicy(QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Expanding)
         else:
-            self.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Fixed)
-        self.setAttribute(Qt.WA_WState_OwnSizePolicy, False)
+            self.setSizePolicy(QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Fixed)
+        self.setAttribute(Qt.WidgetAttribute.WA_WState_OwnSizePolicy, False)
 
     def _updateStatus(self):
         self._stbar.show()
@@ -547,10 +547,10 @@ class CmdControlDialog(QDialog):
     def __init__(self, parent=None):
         super(CmdControlDialog, self).__init__(parent)
         self.setWindowFlags(self.windowFlags()
-                            & ~Qt.WindowContextHelpButtonHint)
+                            & ~Qt.WindowType.WindowContextHelpButtonHint)
 
         vbox = QVBoxLayout()
-        vbox.setSizeConstraint(QLayout.SetMinAndMaxSize)
+        vbox.setSizeConstraint(QLayout.SizeConstraint.SetMinAndMaxSize)
         self.setLayout(vbox)
 
         self.__cmdwidget = None
@@ -558,7 +558,7 @@ class CmdControlDialog(QDialog):
         self.__cmdcontrol = cmd = CmdSessionControlWidget(self)
         cmd.finished.connect(self.done)
         vbox.addWidget(cmd)
-        self.__runbutton = cmd.addButton(_('&Run'), QDialogButtonBox.AcceptRole)
+        self.__runbutton = cmd.addButton(_('&Run'), QDialogButtonBox.ButtonRole.AcceptRole)
         self.__runbutton.clicked.connect(self.runCommand)
 
         self.__updateUi()
@@ -612,7 +612,7 @@ class CmdControlDialog(QDialog):
 
         # set focus to the first item of the command widget
         fw = self.__cmdwidget
-        while fw.focusPolicy() == Qt.NoFocus or not fw.isVisibleTo(self):
+        while fw.focusPolicy() == Qt.FocusPolicy.NoFocus or not fw.isVisibleTo(self):
             fw = fw.nextInFocusChain()
             if fw is self.__cmdwidget or fw is self.__cmdcontrol:
                 # no candidate available
@@ -702,14 +702,14 @@ class CmdSessionDialog(QDialog):
     def __init__(self, parent=None):
         super(CmdSessionDialog, self).__init__(parent)
         self.setWindowFlags(self.windowFlags()
-                            & ~Qt.WindowContextHelpButtonHint)
+                            & ~Qt.WindowType.WindowContextHelpButtonHint)
         self.setWindowTitle(_('TortoiseHg Command Dialog'))
         self.resize(540, 420)
 
         vbox = QVBoxLayout()
         self.setLayout(vbox)
         vbox.setContentsMargins(5, 5, 5, 5)
-        vbox.setSizeConstraint(QLayout.SetMinAndMaxSize)
+        vbox.setSizeConstraint(QLayout.SizeConstraint.SetMinAndMaxSize)
 
         self._cmdcontrol = cmd = CmdSessionControlWidget(self, logVisible=True)
         cmd.finished.connect(self.done)
