@@ -300,7 +300,7 @@ class CommitWidget(QWidget, qtlib.TaskWidget):
 
         self.recentMessagesButton = QToolButton(
             text=_('Copy message'),
-            popupMode=QToolButton.InstantPopup,
+            popupMode=QToolButton.ToolButtonPopupMode.InstantPopup,
             toolTip=_('Copy one of the recent commit messages'))
         m = QMenu(self.recentMessagesButton)
         m.triggered.connect(self.msgSelected)
@@ -367,8 +367,8 @@ class CommitWidget(QWidget, qtlib.TaskWidget):
             self.hasmqbutton = False
 
         self.optionslabel = QLabel()
-        self.optionslabel.setSizePolicy(QSizePolicy.Ignored,
-                                        QSizePolicy.Preferred)
+        self.optionslabel.setSizePolicy(QSizePolicy.Policy.Ignored,
+                                        QSizePolicy.Policy.Preferred)
         vbox.addWidget(self.optionslabel, 0)
 
         self.wdirinfo = revpanel.WDirInfoWidget(repo)
@@ -379,16 +379,15 @@ class CommitWidget(QWidget, qtlib.TaskWidget):
         vbox.addWidget(msgte, 1)
         upperframe = QFrame()
 
-        SP = QSizePolicy
-        sp = SP(SP.Expanding, SP.Expanding)
+        sp = QSizePolicy(QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Expanding)
         sp.setHorizontalStretch(1)
         upperframe.setSizePolicy(sp)
         upperframe.setLayout(vbox)
 
-        self.split = QSplitter(Qt.Vertical)
+        self.split = QSplitter(Qt.Orientation.Vertical)
         if os.name == 'nt':
             self.split.setStyle(QStyleFactory.create('Plastique'))
-        sp = SP(SP.Expanding, SP.Expanding)
+        sp = QSizePolicy(QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Expanding)
         sp.setHorizontalStretch(1)
         sp.setVerticalStretch(0)
         self.split.setSizePolicy(sp)
@@ -485,13 +484,13 @@ class CommitWidget(QWidget, qtlib.TaskWidget):
             def menuButtonWidth(self):
                 style = self.style()
                 opt = self.styleOption()
-                opt.features = QStyleOptionToolButton.MenuButtonPopup
-                rect = style.subControlRect(QStyle.CC_ToolButton, opt,
-                                            QStyle.SC_ToolButtonMenu, self)
+                opt.features = QStyleOptionToolButton.ToolButtonFeature.MenuButtonPopup
+                rect = style.subControlRect(QStyle.ComplexControl.CC_ToolButton, opt,
+                                            QStyle.SubControl.SC_ToolButtonMenu, self)
                 return rect.width()
             def setBold(self):
                 f = self.font()
-                f.setWeight(QFont.Bold)
+                f.setWeight(QFont.Weight.Bold)
                 self.setFont(f)
             def sizeHint(self):
                 # Set the desired width to keep the button from resizing
@@ -499,8 +498,8 @@ class CommitWidget(QWidget, qtlib.TaskWidget):
 
         self.committb = committb = CommitToolButton(self)
         committb.setBold()
-        committb.setPopupMode(QToolButton.MenuButtonPopup)
-        fmk = lambda s: committb.fontMetrics().width(hglib.tounicode(s[2]))
+        committb.setPopupMode(QToolButton.ToolButtonPopupMode.MenuButtonPopup)
+        fmk = lambda s: committb.fontMetrics().horizontalAdvance(hglib.tounicode(s[2]))
         committb._width = (max(pycompat.maplist(fmk, acts))
                            + 4*committb.menuButtonWidth())
 
@@ -532,9 +531,9 @@ class CommitWidget(QWidget, qtlib.TaskWidget):
         self.commitButtonEnable.connect(committb.setEnabled)
         self.commitSetAction(actionName=self._getPreferredActionName())
         sc = QShortcut(QKeySequence('Ctrl+Return'), self, self.mqPerformAction)
-        sc.setContext(Qt.WidgetWithChildrenShortcut)
+        sc.setContext(Qt.ShortcutContext.WidgetWithChildrenShortcut)
         sc = QShortcut(QKeySequence('Ctrl+Enter'), self, self.mqPerformAction)
-        sc.setContext(Qt.WidgetWithChildrenShortcut)
+        sc.setContext(Qt.ShortcutContext.WidgetWithChildrenShortcut)
         return committb
 
     @pyqtSlot(bool)
@@ -774,9 +773,9 @@ class CommitWidget(QWidget, qtlib.TaskWidget):
         dlg = DetailsDialog(self._repoagent, self.opts, self.userhist, self,
                             mode=mode)
         dlg.finished.connect(dlg.deleteLater)
-        dlg.setWindowFlags(Qt.Sheet)
-        dlg.setWindowModality(Qt.WindowModal)
-        if dlg.exec_() == QDialog.Accepted:
+        dlg.setWindowFlags(Qt.WindowType.Sheet)
+        dlg.setWindowModality(Qt.WindowModality.WindowModal)
+        if dlg.exec_() == QDialog.DialogCode.Accepted:
             self.opts.update(dlg.outopts)
             self.refresh()
 
@@ -885,9 +884,9 @@ class CommitWidget(QWidget, qtlib.TaskWidget):
     def branchOp(self):
         # type: () -> None
         d = branchop.BranchOpDialog(self._repoagent, self.branchop, self)
-        d.setWindowFlags(Qt.Sheet)
-        d.setWindowModality(Qt.WindowModal)
-        if d.exec_() == QDialog.Accepted:
+        d.setWindowFlags(Qt.WindowType.Sheet)
+        d.setWindowModality(Qt.WindowModality.WindowModal)
+        if d.exec_() == QDialog.DialogCode.Accepted:
             self.branchop = d.branchop
             if self.branchop is False:
                 if not self.getMessage(True).strip():
@@ -903,8 +902,8 @@ class CommitWidget(QWidget, qtlib.TaskWidget):
     def topicOp(self):
         # type: () -> None
         d = topic.TopicDialog(self._repoagent, self.branchop, self)
-        d.setWindowFlags(Qt.Sheet)
-        d.setWindowModality(Qt.WindowModal)
+        d.setWindowFlags(Qt.WindowType.Sheet)
+        d.setWindowModality(Qt.WindowModality.WindowModal)
         d.exec_()
         self.msgte.setFocus()
         self.refresh()
@@ -923,8 +922,8 @@ class CommitWidget(QWidget, qtlib.TaskWidget):
         if not msg:
             return
         d = QMessageBox.question(self, _('Confirm Undo'), msg,
-                                 QMessageBox.Ok | QMessageBox.Cancel)
-        if d != QMessageBox.Ok:
+                                 QMessageBox.StandardButton.Ok | QMessageBox.StandardButton.Cancel)
+        if d != QMessageBox.StandardButton.Ok:
             return
         self._runCommand('rollback', [['rollback']])
 
@@ -955,8 +954,8 @@ class CommitWidget(QWidget, qtlib.TaskWidget):
         if self.msgte.text() and self.msgte.isModified():
             d = QMessageBox.question(self, _('Confirm Discard Message'),
                         _('Discard current commit message?'),
-                        QMessageBox.Ok | QMessageBox.Cancel)
-            if d != QMessageBox.Ok:
+                        QMessageBox.StandardButton.Ok | QMessageBox.StandardButton.Cancel)
+            if d != QMessageBox.StandardButton.Ok:
                 return
         message = action.data()
         self.setMessage(message)
@@ -1295,8 +1294,8 @@ class DetailsDialog(QDialog):
         usercombo = QComboBox()
         usercombo.setEditable(True)
         usercombo.setEnabled(False)
-        SP = QSizePolicy
-        usercombo.setSizePolicy(SP(SP.Expanding, SP.Minimum))
+
+        usercombo.setSizePolicy(QSizePolicy(QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Minimum))
         self.usercb.toggled.connect(usercombo.setEnabled)
         self.usercb.toggled.connect(lambda s: s and usercombo.setFocus())
 
@@ -1412,8 +1411,8 @@ class DetailsDialog(QDialog):
         recursesave.clicked.connect(self.saveRecurseInSubrepos)
         self.recursecb = QCheckBox(_('Recurse into subrepositories '
                                      '(--subrepos)'))
-        SP = QSizePolicy
-        self.recursecb.setSizePolicy(SP(SP.Expanding, SP.Minimum))
+
+        self.recursecb.setSizePolicy(QSizePolicy(QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Minimum))
         #self.recursecb.toggled.connect(recursesave.setEnabled)
 
         if opts.get('recurseinsubrepos'):
@@ -1423,8 +1422,7 @@ class DetailsDialog(QDialog):
         hbox.addWidget(recursesave)
         layout.addLayout(hbox)
 
-        BB = QDialogButtonBox
-        bb = QDialogButtonBox(BB.Ok|BB.Cancel)
+        bb = QDialogButtonBox(QDialogButtonBox.StandardButton.Ok|QDialogButtonBox.StandardButton.Cancel)
         bb.accepted.connect(self.accept)
         bb.rejected.connect(self.reject)
         self.bb = bb
@@ -1597,7 +1595,7 @@ class CommitDialog(QDialog):
     def __init__(self, repoagent, pats, opts, parent=None):
         # type: (RepoAgent, List[bytes], Dict[Text, bytes], Optional[QObject]) -> None
         QDialog.__init__(self, parent)
-        self.setWindowFlags(Qt.Window)
+        self.setWindowFlags(Qt.WindowType.Window)
         self.setWindowIcon(qtlib.geticon('hg-commit'))
         self._repoagent = repoagent
         self.pats = pats
@@ -1619,15 +1617,14 @@ class CommitDialog(QDialog):
         commit.progress.connect(self.statusbar.progress)
         commit.linkActivated.connect(self.linkActivated)
 
-        BB = QDialogButtonBox
-        bb = QDialogButtonBox(BB.Close|BB.Discard)
+        bb = QDialogButtonBox(QDialogButtonBox.StandardButton.Close|QDialogButtonBox.StandardButton.Discard)
         bb.rejected.connect(self.reject)
-        bb.button(BB.Discard).setText('Undo')
-        bb.button(BB.Discard).clicked.connect(commit.rollback)
-        bb.button(BB.Close).setDefault(False)
-        bb.button(BB.Discard).setDefault(False)
+        bb.button(QDialogButtonBox.StandardButton.Discard).setText('Undo')
+        bb.button(QDialogButtonBox.StandardButton.Discard).clicked.connect(commit.rollback)
+        bb.button(QDialogButtonBox.StandardButton.Close).setDefault(False)
+        bb.button(QDialogButtonBox.StandardButton.Discard).setDefault(False)
         self.commitButton = commit.commitSetupButton()
-        bb.addButton(self.commitButton, BB.AcceptRole)
+        bb.addButton(self.commitButton, QDialogButtonBox.ButtonRole.AcceptRole)
 
         self.bb = bb
 
@@ -1648,7 +1645,7 @@ class CommitDialog(QDialog):
         self.commit.reload()
         self.updateUndo()
         self.commit.msgte.setFocus()
-        qtlib.newshortcutsforstdkey(QKeySequence.Refresh, self, self.refresh)
+        qtlib.newshortcutsforstdkey(QKeySequence.StandardKey.Refresh, self, self.refresh)
 
     def linkActivated(self, link):
         # type: (Text) -> None
@@ -1664,14 +1661,13 @@ class CommitDialog(QDialog):
     @pyqtSlot()
     def updateUndo(self):
         # type: () -> None
-        BB = QDialogButtonBox
         undomsg = self.commit.canUndo()
         if undomsg:
-            self.bb.button(BB.Discard).setEnabled(True)
-            self.bb.button(BB.Discard).setToolTip(undomsg)
+            self.bb.button(QDialogButtonBox.StandardButton.Discard).setEnabled(True)
+            self.bb.button(QDialogButtonBox.StandardButton.Discard).setToolTip(undomsg)
         else:
-            self.bb.button(BB.Discard).setEnabled(False)
-            self.bb.button(BB.Discard).setToolTip('')
+            self.bb.button(QDialogButtonBox.StandardButton.Discard).setEnabled(False)
+            self.bb.button(QDialogButtonBox.StandardButton.Discard).setToolTip('')
 
     def refresh(self):
         # type: () -> None
