@@ -154,7 +154,7 @@ class FilectxActions(QObject):
                 act.setIcon(qtlib.geticon(icon))
             if key:
                 qtlib.setContextMenuShortcut(act, key)
-                act.setShortcutContext(Qt.WidgetWithChildrenShortcut)
+                act.setShortcutContext(Qt.ShortcutContext.WidgetWithChildrenShortcut)
             if tip:
                 act.setStatusTip(tip)
             act.triggered.connect(getattr(self, name))
@@ -318,7 +318,8 @@ class FilectxActions(QObject):
             dlg.exec_()
 
     @actionSlot(_('&View at Revision'), 'view-at-revision', 'Shift+Ctrl+E',
-                _('View file as it appeared at this revision'),
+                _('View file as it appeared at this revision using the '
+                  'visual editor'),
                 _committed)
     def editFile(self, fds):
         self._editFileAt(fds, fds[0].rawContext())
@@ -331,6 +332,22 @@ class FilectxActions(QObject):
                  for filename in filenames]
         qtlib.editfiles(repo, files, parent=self._parentWidget())
 
+    @actionSlot(_('&Open at Revision'), 'open-at-revision', None,
+                _("Open file as it appeared at this revision using the "
+                  "system's default application for this file type"),
+                _committed)
+    def openFile(self, fds):
+        self._openFileAt(fds, fds[0].rawContext())
+
+    def _openFileAt(self, fds, ctx):
+        repo = self._repoAgentFor(fds[0]).rawRepo()
+        filenames = _lcanonpaths(fds)
+        base, _ = visdiff.snapshot(repo, filenames, ctx)
+        files = [os.path.join(base, filename)
+                 for filename in filenames]
+        for f in files:
+            qtlib.openlocalurl(f)
+
     @actionSlot(_('&Save at Revision...'), None, 'Shift+Ctrl+S',
                 _('Save file as it appeared at this revision'),
                 _committed)
@@ -357,7 +374,8 @@ class FilectxActions(QObject):
             self._runCommandSequence(cmdlines)
 
     @actionSlot(_('&Edit Local'), 'edit-file', None,
-                _('Edit current file in working copy'),
+                _('Edit current file(s) in working copy with the visual '
+                  'editor'),
                 (_isfile, _filestatus('MACI?')))
     def editLocalFile(self, fds):
         repo = self._repoAgentFor(fds[0]).rawRepo()
@@ -365,7 +383,8 @@ class FilectxActions(QObject):
         qtlib.editfiles(repo, filenames, parent=self._parentWidget())
 
     @actionSlot(_('&Open Local'), None, 'Shift+Ctrl+L',
-                _('Edit current file in working copy'),
+                _("Open current file(s) in working copy with the system's "
+                  "default application for this file type"),
                 (_isfile, _filestatus('MACI?')))
     def openLocalFile(self, fds):
         repo = self._repoAgentFor(fds[0]).rawRepo()
@@ -437,7 +456,7 @@ class FilectxActions(QObject):
             else:
                 ctx = fd.rawContext()
                 spath = hglib.fromunicode(fd.canonicalFilePath())
-                revid = ctx.substate[spath][1]
+                revid = hglib.tounicode(ctx.substate[spath][1])
                 link = 'repo:%s?%s' % (fd.absoluteFilePath(), revid)
             self.linkActivated.emit(link)
 
@@ -492,7 +511,7 @@ class FilectxActions(QObject):
         name = str(action.data())
         fdfilters = self._customactions[name][1]
         fds = _filterby(fdfilters, self._selfds)
-        files = [hglib.fromunicode(fd.filePath()) for fd in fds]
+        files = [fd.filePath() for fd in fds]
         self.runCustomCommandRequested.emit(name, files)
 
 
@@ -509,7 +528,7 @@ class WctxActions(FilectxActions):
         # the same shortcut as editFile that is disabled for working rev
         a = self.action('editLocalFile')
         qtlib.setContextMenuShortcut(a, 'Ctrl+Shift+E')
-        a.setShortcutContext(Qt.WidgetWithChildrenShortcut)
+        a.setShortcutContext(Qt.ShortcutContext.WidgetWithChildrenShortcut)
         a = self.action('addLargefile')
         a.setVisible(b'largefiles' in repo.extensions())
         self._addAction('renameFileMenu', *self._createRenameFileMenu())
