@@ -27,6 +27,15 @@ from tortoisehg.util import hglib, patchctx
 from tortoisehg.util.i18n import _
 from tortoisehg.hgqt import fileencoding
 
+if hglib.TYPE_CHECKING:
+    from typing import (
+        Any,
+        List,
+        Text,
+        Tuple,
+    )
+
+
 forcedisplaymsg = _('Display the file anyway')
 
 class _BadContent(Exception):
@@ -115,7 +124,9 @@ class _AbstractFileData(object):
 
     def __repr__(self):
         return '<%s %s@%s>' % (self.__class__.__name__,
-                               posixpath.join(self._rpath, self._wfile),
+                               hglib.tounicode(
+                                   posixpath.join(self._rpath, self._wfile)
+                               ),
                                self._ctx)
 
     def isLoaded(self):
@@ -385,7 +396,7 @@ class FileData(_AbstractFileData):
             diffopts = patch.difffeatureopts(repo.ui)
             diffopts.git = True
             m = scmutil.matchfiles(repo, [wfile])
-            fp = pycompat.bytesio()
+            fp = util.bytesio()
 
             copy = {}
             if oldname != wfile:
@@ -409,7 +420,7 @@ class FileData(_AbstractFileData):
             values = []
             lines = 0
             for chunk in self.changes.hunks:
-                buf = pycompat.bytesio()
+                buf = util.bytesio()
                 chunk.write(buf)
                 chunk.excluded = False
                 val = buf.getvalue()
@@ -581,11 +592,12 @@ class SubrepoData(_AbstractFileData):
         try:
             def genSubrepoRevChangedDescription(subrelpath, sfrom, sto,
                                                 repo):
+                # type: (bytes, Text, Text, Any) -> Tuple[List[Text], Text]
                 """Generate a subrepository revision change description"""
                 out = []
                 def getLog(_ui, srepo, opts):
                     if srepo is None:
-                        return _('changeset: %s') % opts['rev'][0][:12]
+                        return _('changeset: %s') % hglib.tounicode(opts['rev'][0][:12])
                     _ui.pushbuffer()
                     logOutput = b''
                     try:
@@ -600,16 +612,17 @@ class SubrepoData(_AbstractFileData):
                         # case, add a warning to the output, but try to
                         # get the revision information anyway
                         for n, rev in enumerate(opts['rev']):
-                            if rev.endswith('+'):
+                            if rev.endswith(b'+'):
                                 logOutput += hglib.fromunicode(
                                     _('[WARNING] Invalid subrepo '
-                                      'revision ID:\n\t%s\n\n') % rev)
+                                      'revision ID:\n\t%s\n\n')
+                                    % hglib.tounicode(rev))
                                 opts['rev'][n] = rev[:-1]
                         commands.log(_ui, srepo, **opts)
                         logOutput += _ui.popbuffer()
                     return hglib.tounicode(logOutput)
 
-                opts = {'date':None, 'rev':[sfrom]}
+                opts = {'date':None, 'rev':[hglib.fromunicode(sfrom)]}
                 subabspath = os.path.join(repo.root, subrelpath)
                 missingsub = srepo is None or not os.path.isdir(subabspath)
                 sfromlog = ''
@@ -634,7 +647,8 @@ class SubrepoData(_AbstractFileData):
                                + u'\n\n')
                     out.append(_('Previously the subrepository was '
                                  'at the following revision:') + u'\n\n')
-                    subinfo = getLog(_ui, srepo, {'rev': [sfrom]})
+                    subinfo = getLog(_ui, srepo,
+                                     {'rev': [hglib.fromunicode(sfrom)]})
                     slog = hglib.tounicode(subinfo)
                     out.append(slog)
                     return out, sstatedesc
@@ -682,7 +696,7 @@ class SubrepoData(_AbstractFileData):
                         'directory.') + '\n'
                 else:
                     try:
-                        opts['rev'] = [sto]
+                        opts['rev'] = [hglib.fromunicode(sto)]
                         stolog = getLog(_ui, srepo, opts)
                     except error.RepoError:
                         header = _(
@@ -700,7 +714,9 @@ class SubrepoData(_AbstractFileData):
 
                 return out, sstatedesc
 
-            srev = ctx.substate.get(wfile, hglib.nullsubrepostate)[1]
+            srev = hglib.tounicode(
+                ctx.substate.get(wfile, hglib.nullsubrepostate)[1]
+            )
             srepo = None
             subabspath = os.path.join(ctx.repo().root, wfile)
             sactual = ''
@@ -710,7 +726,7 @@ class SubrepoData(_AbstractFileData):
                     if isinstance(sub, subrepo.hgsubrepo):
                         srepo = sub._repo
                         if srepo is not None:
-                            sactual = srepo[b'.'].hex()
+                            sactual = hglib.tounicode(srepo[b'.'].hex())
                     else:
                         self.error = _('Not a Mercurial subrepo, not '
                                        'previewable')
@@ -745,7 +761,9 @@ class SubrepoData(_AbstractFileData):
 
             sstatedesc = 'changed'
             if ctx.rev() is not None:
-                sparent = ctx2.substate.get(wfile, hglib.nullsubrepostate)[1]
+                sparent = hglib.tounicode(
+                    ctx2.substate.get(wfile, hglib.nullsubrepostate)[1]
+                )
                 subrepochange, sstatedesc = \
                     genSubrepoRevChangedDescription(wfile,
                         sparent, srev, ctx.repo())
@@ -803,7 +821,9 @@ def createDirData(ctx, pctx, path, rpath=None):
 
 def createSubrepoData(ctx, pctx, path, status=None, rpath=None, subkind=None):
     if not subkind:
-        subkind = ctx.substate.get(path, hglib.nullsubrepostate)[2]
+        subkind = pycompat.sysstr(
+            ctx.substate.get(path, hglib.nullsubrepostate)[2]
+        )
     # TODO: replace 'S' by subrepo's status
     return SubrepoData(ctx, pctx, path, 'S', rpath, subkind)
 
