@@ -100,7 +100,7 @@ class SearchWidget(QWidget, qtlib.TaskWidget):
         bt = QPushButton(_('Search'))
         bt.setDefault(True)
         f = bt.font()
-        f.setWeight(QFont.Bold)
+        f.setWeight(QFont.Weight.Bold)
         bt.setFont(f)
         cbt = QPushButton(_('Stop'))
         cbt.setEnabled(False)
@@ -146,7 +146,7 @@ class SearchWidget(QWidget, qtlib.TaskWidget):
         grid.setColumnStretch(3, 1)
         grid.setColumnStretch(1, 0)
         frame = QFrame()
-        frame.setFrameStyle(QFrame.StyledPanel)
+        frame.setFrameStyle(QFrame.Shape.StyledPanel)
         revision.toggled.connect(self._onRevisionToggled)
         history.toggled.connect(singlematch.setDisabled)
         revle.setEnabled(False)
@@ -267,7 +267,7 @@ class SearchWidget(QWidget, qtlib.TaskWidget):
         checked = self.wctxradio.isChecked()
         try:
             wctx = self.repo[None]
-            if '.hgsubstate' in wctx:
+            if b'.hgsubstate' in wctx:
                 self.recurse.setEnabled(checked)
             else:
                 self.recurse.setEnabled(False)
@@ -297,7 +297,7 @@ class SearchWidget(QWidget, qtlib.TaskWidget):
             self.thread.wait(2000)
 
     def keyPressEvent(self, event):
-        if (event.key() == Qt.Key_Escape
+        if (event.key() == Qt.Key.Key_Escape
             and self.thread and self.thread.isRunning()):
             self.stopClicked()
         else:
@@ -600,11 +600,11 @@ class MatchTree(QTableView):
         self.selectedRows = ()
 
         self.delegate = htmldelegate.HTMLDelegate(self)
-        self.setDragDropMode(QTableView.DragOnly)
+        self.setDragDropMode(QTableView.DragDropMode.DragOnly)
         self.setItemDelegateForColumn(COL_TEXT, self.delegate)
-        self.setSelectionMode(QTableView.ExtendedSelection)
-        self.setSelectionBehavior(QAbstractItemView.SelectRows)
-        self.setContextMenuPolicy(Qt.CustomContextMenu)
+        self.setSelectionMode(QTableView.SelectionMode.ExtendedSelection)
+        self.setSelectionBehavior(QAbstractItemView.SelectionBehavior.SelectRows)
+        self.setContextMenuPolicy(Qt.ContextMenuPolicy.CustomContextMenu)
         self.setShowGrid(False)
         vh = self.verticalHeader()
         vh.hide()
@@ -770,21 +770,21 @@ class MatchModel(QAbstractTableModel):
     def columnCount(self, parent=QModelIndex()):
         return len(self.headers)
 
-    def data(self, index, role=Qt.DisplayRole):
+    def data(self, index, role=Qt.ItemDataRole.DisplayRole):
         if not index.isValid():
             return None
-        if role == Qt.DisplayRole:
+        if role == Qt.ItemDataRole.DisplayRole:
             return self.rows[index.row()][index.column()]
         return None
 
-    def headerData(self, col, orientation, role=Qt.DisplayRole):
-        if role != Qt.DisplayRole or orientation != Qt.Horizontal:
+    def headerData(self, col, orientation, role=Qt.ItemDataRole.DisplayRole):
+        if role != Qt.ItemDataRole.DisplayRole or orientation != Qt.Orientation.Horizontal:
             return None
         else:
             return self.headers[col]
 
     def flags(self, index):
-        flags = Qt.ItemIsSelectable | Qt.ItemIsEnabled | Qt.ItemIsDragEnabled
+        flags = Qt.ItemFlag.ItemIsSelectable | Qt.ItemFlag.ItemIsEnabled | Qt.ItemFlag.ItemIsDragEnabled
         return flags
 
     def mimeTypes(self):
@@ -818,7 +818,7 @@ class MatchModel(QAbstractTableModel):
     def sort(self, col, order):
         self.layoutAboutToBeChanged.emit()
         self.rows.sort(key=lambda x: x[col],
-                       reverse=(order == Qt.DescendingOrder))
+                       reverse=(order == Qt.SortOrder.DescendingOrder))
         self.layoutChanged.emit()
 
     ## Custom methods
@@ -843,7 +843,7 @@ class MatchModel(QAbstractTableModel):
 class SearchDialog(QDialog):
     def __init__(self, repoagent, upats, parent=None, **opts):
         super(SearchDialog, self).__init__(parent)
-        self.setWindowFlags(Qt.Window)
+        self.setWindowFlags(Qt.WindowType.Window)
         self.setWindowIcon(qtlib.geticon('view-filter'))
         self.setWindowTitle(_('TortoiseHg Search'))
 
