@@ -20,11 +20,11 @@ from .qtcore import (
     pyqtSlot,
 )
 from .qtgui import (
+    QApplication,
     QCheckBox,
     QDialog,
     QDialogButtonBox,
     QVBoxLayout,
-    qApp,
 )
 
 from hgext.largefiles import (
@@ -51,7 +51,7 @@ class PurgeDialog(QDialog):
     def __init__(self, repoagent, parent=None):
         QDialog.__init__(self, parent)
         f = self.windowFlags()
-        self.setWindowFlags(f & ~Qt.WindowContextHelpButtonHint)
+        self.setWindowFlags(f & ~Qt.WindowType.WindowContextHelpButtonHint)
 
         self._repoagent = repoagent
 
@@ -90,8 +90,7 @@ class PurgeDialog(QDialog):
         self.hgfilecb.setChecked(True)
         toplayout.addWidget(self.hgfilecb)
 
-        BB = QDialogButtonBox
-        bb = QDialogButtonBox(BB.Ok|BB.Cancel)
+        bb = QDialogButtonBox(QDialogButtonBox.StandardButton.Ok|QDialogButtonBox.StandardButton.Cancel)
         bb.accepted.connect(self.accept)
         bb.rejected.connect(self.reject)
         self.bb = bb
@@ -109,7 +108,7 @@ class PurgeDialog(QDialog):
         self.bb.setEnabled(False)
         self.progress.emit(*cmdui.startProgress(_('Checking'), '...'))
         s = QSettings()
-        desktopgeom = qApp.desktop().availableGeometry()
+        desktopgeom = QApplication.primaryScreen().availableGeometry()
         self.resize(desktopgeom.size() * 0.25)
         self.restoreGeometry(qtlib.readByteArray(s, 'purge/geom'))
 
