@@ -35,6 +35,7 @@ from .qtcore import (
 )
 from .qtgui import (
     QAction,
+    QApplication,
     QCheckBox,
     QDialog,
     QDialogButtonBox,
@@ -45,7 +46,6 @@ from .qtgui import (
     QMenu,
     QToolBar,
     QVBoxLayout,
-    qApp,
 )
 
 from ..util import hglib
@@ -166,7 +166,7 @@ class ScintillaCompat(QsciScintilla):
             self._imsupport = _SciImSupport(self)
 
         def inputMethodQuery(self, query):
-            if query == Qt.ImMicroFocus:
+            if query == Qt.InputMethodQuery.ImCursorRectangle:
                 # a rectangle (in viewport coords) including the cursor
                 l, i = self.getCursorPosition()
                 p = self.positionFromLineIndex(l, i)
@@ -189,7 +189,7 @@ class ScintillaCompat(QsciScintilla):
                                       event.commitString())
             self._imsupport.insertpreedit(event.preeditString())
             for a in event.attributes():
-                if a.type == QInputMethodEvent.Cursor:
+                if a.type == QInputMethodEvent.AttributeType.Cursor:
                     self._imsupport.movepreeditcursor(a.start)
                 # TextFormat is not supported
 
@@ -198,8 +198,8 @@ class ScintillaCompat(QsciScintilla):
     # QScintilla 2.5 can translate Backtab to Shift+SCK_TAB (issue #82)
     if QSCINTILLA_VERSION < 0x20500:
         def keyPressEvent(self, event):
-            if event.key() == Qt.Key_Backtab:
-                event = QKeyEvent(event.type(), Qt.Key_Tab, Qt.ShiftModifier)
+            if event.key() == Qt.Key.Key_Backtab:
+                event = QKeyEvent(event.type(), Qt.Key.Key_Tab, Qt.KeyboardModifier.ShiftModifier)
             super(ScintillaCompat, self).keyPressEvent(event)
 
     if not hasattr(QsciScintilla, 'createStandardContextMenu'):
@@ -209,27 +209,27 @@ class ScintillaCompat(QsciScintilla):
             menu = QMenu(self)
             if not self.isReadOnly():
                 a = menu.addAction(_('&Undo'), self.undo)
-                a.setShortcuts(QKeySequence.Undo)
+                a.setShortcuts(QKeySequence.StandardKey.Undo)
                 a.setEnabled(self.isUndoAvailable())
                 a = menu.addAction(_('&Redo'), self.redo)
-                a.setShortcuts(QKeySequence.Redo)
+                a.setShortcuts(QKeySequence.StandardKey.Redo)
                 a.setEnabled(self.isRedoAvailable())
                 menu.addSeparator()
                 a = menu.addAction(_('Cu&t'), self.cut)
-                a.setShortcuts(QKeySequence.Cut)
+                a.setShortcuts(QKeySequence.StandardKey.Cut)
                 a.setEnabled(self.hasSelectedText())
             a = menu.addAction(_('&Copy'), self.copy)
-            a.setShortcuts(QKeySequence.Copy)
+            a.setShortcuts(QKeySequence.StandardKey.Copy)
             a.setEnabled(self.hasSelectedText())
             if not self.isReadOnly():
                 a = menu.addAction(_('&Paste'), self.paste)
-                a.setShortcuts(QKeySequence.Paste)
+                a.setShortcuts(QKeySequence.StandardKey.Paste)
                 a = menu.addAction(_('&Delete'), self.removeSelectedText)
-                a.setShortcuts(QKeySequence.Delete)
+                a.setShortcuts(QKeySequence.StandardKey.Delete)
                 a.setEnabled(self.hasSelectedText())
             menu.addSeparator()
             a = menu.addAction(_('Select &All'), self.selectAll)
-            a.setShortcuts(QKeySequence.SelectAll)
+            a.setShortcuts(QKeySequence.StandardKey.SelectAll)
             return menu
 
     # compability mode with QScintilla from Ubuntu 10.04
@@ -286,7 +286,7 @@ class Scintilla(ScintillaCompat):
         super(Scintilla, self).__init__(parent)
         self.autoUseTabs = True
         self.setUtf8(True)
-        self.setWrapVisualFlags(QsciScintilla.WrapFlagByBorder)
+        self.setWrapVisualFlags(QsciScintilla.WrapVisualFlag.WrapFlagByBorder)
         self.textChanged.connect(self._resetfindcond)
         self._resetfindcond()
         self.highlightLines = set()
@@ -323,9 +323,9 @@ class Scintilla(ScintillaCompat):
 
         wrapmenu = menu.addMenu(_('&Wrap'))
         wrapmenu.triggered.connect(self._setWrapModeByMenu)
-        for name, mode in ((_('&None', 'wrap mode'), qsci.WrapNone),
-                           (_('&Word'), qsci.WrapWord),
-                           (_('&Character'), qsci.WrapCharacter)):
+        for name, mode in ((_('&None', 'wrap mode'), qsci.WrapMode.WrapNone),
+                           (_('&Word'), qsci.WrapMode.WrapWord),
+                           (_('&Character'), qsci.WrapMode.WrapCharacter)):
             a = wrapmenu.addAction(name)
             a.setCheckable(True)
             a.setChecked(self.wrapMode() == mode)
@@ -334,9 +334,9 @@ class Scintilla(ScintillaCompat):
         menu.addSeparator()
         wsmenu = menu.addMenu(_('White&space'))
         wsmenu.triggered.connect(self._setWhitespaceVisibilityByMenu)
-        for name, mode in ((_('&Visible'), qsci.WsVisible),
-                           (_('&Invisible'), qsci.WsInvisible),
-                           (_('&AfterIndent'), qsci.WsVisibleAfterIndent)):
+        for name, mode in ((_('&Visible'), qsci.WhitespaceVisibility.WsVisible),
+                           (_('&Invisible'), qsci.WhitespaceVisibility.WsInvisible),
+                           (_('&AfterIndent'), qsci.WhitespaceVisibility.WsVisibleAfterIndent)):
             a = wsmenu.addAction(name)
             a.setCheckable(True)
             a.setChecked(self.whitespaceVisibility() == mode)
@@ -367,9 +367,9 @@ class Scintilla(ScintillaCompat):
         if not self.isReadOnly():
             eolmodemenu = menu.addMenu(_('EOL &Mode'))
             eolmodemenu.triggered.connect(self._setEolModeByMenu)
-            for name, mode in ((_('&Windows'), qsci.EolWindows),
-                               (_('&Unix'), qsci.EolUnix),
-                               (_('&Mac'), qsci.EolMac)):
+            for name, mode in ((_('&Windows'), qsci.EolMode.EolWindows),
+                               (_('&Unix'), qsci.EolMode.EolUnix),
+                               (_('&Mac'), qsci.EolMode.EolMac)):
                 a = eolmodemenu.addAction(name)
                 a.setCheckable(True)
                 a.setChecked(self.eolMode() == mode)
@@ -382,8 +382,13 @@ class Scintilla(ScintillaCompat):
             a.setChecked(self.autoCompletionThreshold() > 0)
 
     def saveSettings(self, qs, prefix):
-        qs.setValue(prefix+'/wrap', self.wrapMode())
-        qs.setValue(prefix+'/whitespace', self.whitespaceVisibility())
+        if QT_VERSION >= 0x60000:
+            value = lambda e: e.value
+        else:
+            value = lambda e: e
+
+        qs.setValue(prefix+'/wrap', value(self.wrapMode()))
+        qs.setValue(prefix+'/whitespace', value(self.whitespaceVisibility()))
         qs.setValue(prefix+'/eol', self.eolVisibility())
         if self.autoUseTabs:
             qs.setValue(prefix+'/usetabs', -1)
@@ -392,8 +397,14 @@ class Scintilla(ScintillaCompat):
         qs.setValue(prefix+'/autocomplete', self.autoCompletionThreshold())
 
     def loadSettings(self, qs, prefix):
-        self.setWrapMode(qtlib.readInt(qs, prefix + '/wrap'))
-        self.setWhitespaceVisibility(qtlib.readInt(qs, prefix + '/whitespace'))
+        self.setWrapMode(
+            QsciScintilla.WrapMode(qtlib.readInt(qs, prefix + '/wrap'))
+        )
+        self.setWhitespaceVisibility(
+            QsciScintilla.WhitespaceVisibility(
+                qtlib.readInt(qs, prefix + '/whitespace')
+            )
+        )
         self.setEolVisibility(qtlib.readBool(qs, prefix + '/eol'))
         # usetabs = -1, False, or True
         usetabs = qtlib.readInt(qs, prefix + '/usetabs')
@@ -544,8 +555,8 @@ class SearchToolBar(QToolBar):
         self.setIconSize(qtlib.smallIconSize())
 
         a = self.addAction(qtlib.geticon('window-close'), '')
-        a.setShortcut(Qt.Key_Escape)
-        a.setShortcutContext(Qt.WidgetWithChildrenShortcut)
+        a.setShortcut(Qt.Key.Key_Escape)
+        a.setShortcutContext(Qt.ShortcutContext.WidgetWithChildrenShortcut)
         a.triggered.connect(self.hide)
         self.addWidget(qtlib.Spacer(2, 2))
 
@@ -560,15 +571,15 @@ class SearchToolBar(QToolBar):
         self.addWidget(self._wrapchk)
 
         self._prevact = self.addAction(qtlib.geticon('go-up'), _('Prev'))
-        self._prevact.setShortcuts(QKeySequence.FindPrevious)
+        self._prevact.setShortcuts(QKeySequence.StandardKey.FindPrevious)
         self._nextact = self.addAction(qtlib.geticon('go-down'), _('Next'))
-        self._nextact.setShortcuts(QKeySequence.FindNext)
+        self._nextact.setShortcuts(QKeySequence.StandardKey.FindNext)
         for a in [self._prevact, self._nextact]:
-            a.setShortcutContext(Qt.WidgetWithChildrenShortcut)
+            a.setShortcutContext(Qt.ShortcutContext.WidgetWithChildrenShortcut)
             a.triggered.connect(self._emitSearchRequested)
             w = self.widgetForAction(a)
             w.setAutoRaise(False)  # no flat button
-            w.setToolButtonStyle(Qt.ToolButtonTextBesideIcon)
+            w.setToolButtonStyle(Qt.ToolButtonStyle.ToolButtonTextBesideIcon)
 
         self._le.textChanged.connect(self._updateSearchButtons)
 
@@ -587,7 +598,7 @@ class SearchToolBar(QToolBar):
         self._updateSearchButtons()
 
     def keyPressEvent(self, event):
-        if event.key() in (Qt.Key_Enter, Qt.Key_Return):
+        if event.key() in (Qt.Key.Key_Enter, Qt.Key.Key_Return):
             return  # handled by returnPressed
         super(SearchToolBar, self).keyPressEvent(event)
 
@@ -678,15 +689,15 @@ class KeyPressInterceptor(QObject):
 
     def __init__(self, parent=None, keys=None, keyseqs=None):
         super(KeyPressInterceptor, self).__init__(parent)
-        self._keys = {Qt.Key_Escape}
-        self._keyseqs = [QKeySequence.Refresh]
+        self._keys = {Qt.Key.Key_Escape}
+        self._keyseqs = [QKeySequence.StandardKey.Refresh]
         if keys:
             self._keys.update(keys)
         if keyseqs:
             self._keyseqs.extend(keyseqs)
 
     def eventFilter(self, watched, event):
-        if event.type() != QEvent.KeyPress:
+        if event.type() != QEvent.Type.KeyPress:
             return super(KeyPressInterceptor, self).eventFilter(
                 watched, event)
         if self._isinterceptable(event):
@@ -704,7 +715,7 @@ class KeyPressInterceptor(QObject):
 def unbindConflictedKeys(sci):
     cmdset = sci.standardCommands()
     try:
-        cmd = cmdset.boundTo(Qt.CTRL + Qt.Key_L)
+        cmd = cmdset.boundTo(Qt.Modifier.CTRL + Qt.Key.Key_L)
         if cmd:
             cmd.setKey(0)
     except AttributeError:  # old QScintilla does not have boundTo()
@@ -712,17 +723,17 @@ def unbindConflictedKeys(sci):
 
 def qsciEolModeFromOs():
     if os.name.startswith('nt'):
-        return QsciScintilla.EolWindows
+        return QsciScintilla.EolMode.EolWindows
     else:
-        return QsciScintilla.EolUnix
+        return QsciScintilla.EolMode.EolUnix
 
 def qsciEolModeFromLine(line):
     if line.endswith('\r\n'):
-        return QsciScintilla.EolWindows
+        return QsciScintilla.EolMode.EolWindows
     elif line.endswith('\r'):
-        return QsciScintilla.EolMac
+        return QsciScintilla.EolMode.EolMac
     elif line.endswith('\n'):
-        return QsciScintilla.EolUnix
+        return QsciScintilla.EolMode.EolUnix
     else:
         return qsciEolModeFromOs()
 
@@ -736,7 +747,7 @@ def findTabIndentsInLines(lines, linestocheck=100):
 
 def readFile(editor, filename, encoding=None):
     f = QFile(filename)
-    if not f.open(QIODevice.ReadOnly):
+    if not f.open(QIODevice.OpenModeFlag.ReadOnly):
         qtlib.WarningMsgBox(_('Unable to read file'),
                             _('Could not open the specified file for reading.'),
                             f.errorString(), parent=editor)
@@ -792,7 +803,7 @@ def writeFile(editor, filename, encoding=None):
         return False
 
     f = QFile(filename)
-    if not f.open(QIODevice.WriteOnly):
+    if not f.open(QIODevice.OpenModeFlag.WriteOnly):
         qtlib.WarningMsgBox(_('Unable to write file'),
                             _('Could not open the specified file for writing.'),
                             f.errorString(), parent=editor)
@@ -811,12 +822,12 @@ def fileEditor(filename, **opts):
     """Open a simple modal file editing dialog"""
     dialog = QDialog()
     dialog.setWindowFlags(dialog.windowFlags()
-                          & ~Qt.WindowContextHelpButtonHint
-                          | Qt.WindowMaximizeButtonHint)
+                          & ~Qt.WindowType.WindowContextHelpButtonHint
+                          | Qt.WindowType.WindowMaximizeButtonHint)
     dialog.setWindowTitle(filename)
     dialog.setLayout(QVBoxLayout())
     editor = Scintilla()
-    editor.setBraceMatching(QsciScintilla.SloppyBraceMatch)
+    editor.setBraceMatching(QsciScintilla.BraceMatch.SloppyBraceMatch)
     editor.installEventFilter(KeyPressInterceptor(dialog))
     editor.setMarginLineNumbers(1, True)
     editor.setMarginWidth(1, '000')
@@ -827,7 +838,7 @@ def fileEditor(filename, **opts):
     editor.setLexer(lexer)
 
     if opts.get('foldable'):
-        editor.setFolding(QsciScintilla.BoxedTreeFoldStyle)
+        editor.setFolding(QsciScintilla.FoldStyle.BoxedTreeFoldStyle)
     dialog.layout().addWidget(editor)
 
     searchbar = SearchToolBar(dialog)
@@ -839,29 +850,28 @@ def fileEditor(filename, **opts):
         if text:
             searchbar.setPattern(text)
         searchbar.show()
-        searchbar.setFocus(Qt.OtherFocusReason)
-    qtlib.newshortcutsforstdkey(QKeySequence.Find, dialog, showsearchbar)
+        searchbar.setFocus(Qt.FocusReason.OtherFocusReason)
+    qtlib.newshortcutsforstdkey(QKeySequence.StandardKey.Find, dialog, showsearchbar)
     dialog.addActions(searchbar.editorActions())
     dialog.layout().addWidget(searchbar)
 
-    BB = QDialogButtonBox
-    bb = QDialogButtonBox(BB.Save|BB.Cancel)
+    bb = QDialogButtonBox(QDialogButtonBox.StandardButton.Save|QDialogButtonBox.StandardButton.Cancel)
     bb.accepted.connect(dialog.accept)
     bb.rejected.connect(dialog.reject)
     dialog.layout().addWidget(bb)
 
     s = QSettings()
     geomname = 'editor-geom'
-    desktopgeom = qApp.desktop().availableGeometry()
+    desktopgeom = QApplication.primaryScreen().availableGeometry()
     dialog.resize(desktopgeom.size() * 0.5)
     dialog.restoreGeometry(qtlib.readByteArray(s, geomname))
 
     if not readFile(editor, filename):
-        return QDialog.Rejected
+        return QDialog.DialogCode.Rejected
     ret = dialog.exec_()
-    if ret != QDialog.Accepted:
+    if ret != QDialog.DialogCode.Accepted:
         return ret
     if not writeFile(editor, filename):
-        return QDialog.Rejected
+        return QDialog.DialogCode.Rejected
     s.setValue(geomname, dialog.saveGeometry())
     return ret
