@@ -1406,7 +1406,7 @@ def parsecmdline(cmdline, cwd):
     else:
         # shlex can't process non-ASCII unicode on Python 2
         cmdline = cmdline.encode('utf-8')
-        src = pycompat.bytesio(cmdline)
+        src = util.bytesio(cmdline)
         lex = shlex.shlex(src, posix=True)  # pytype: disable=wrong-arg-types
         def decode_token(e):
             return e.decode('utf-8')  # pytype: disable=attribute-error
